# Confirmation AW1

## Description

The confirmation_aw1 skill is for handling registrations in Agent World 1.

## Handlers

* contract_api: handles contract_api messages.
* ledger_api: handles ledger_api messages.
* registration: handles register messages.
* signing: handles signing messages.

## Models

* strategy: contains the confirmation configuration
